@@ -291,7 +291,7 @@ def FieldDetermination(Fields):
     import numpy as np
     import pandas as pd
 
-    objects = pd.DataFrame(columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
+    fields = pd.DataFrame(columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
     for i in range(Fields):
         print('Enter the object type '+ str(i+1) + " (0 - circular, 1 - rectangular):")
         objectType = int(input())
@@ -313,7 +313,7 @@ def FieldDetermination(Fields):
             print('Enter the field\'s width value ' + str(i+1) + ':')
             width = int(input())
             df2 = pd.DataFrame([[objectType, 'null','null' , 'null' ,aX,aY,height,width]], columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
-        fields = objects.append(df2, ignore_index=True)
+        fields = fields.append(df2, ignore_index=True)
         
     return fields
 
